// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
// This module is a shim for the plugin consumer in the browser
export function useIdentityPlugin(_plugin) {
    throw new Error("Identity plugins are not supported in browser environments.");
}//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/3fe68d450d4918f375c155b26a3a8e08f25b4e92/node_modules/@azure/identity/dist/browser/plugins/consumer-browser.mjs.map