// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export {};//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/3fe68d450d4918f375c155b26a3a8e08f25b4e92/node_modules/@azure/identity/dist/esm/credentials/azurePipelinesCredentialOptions.js.map