// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
/**
 * Default key used to access the XML attributes.
 */
export const XML_ATTRKEY = "$";
/**
 * Default key used to access the XML value content.
 */
export const XML_CHARKEY = "_";//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/3fe68d450d4918f375c155b26a3a8e08f25b4e92/node_modules/@azure/core-client/dist/esm/interfaces.js.map