// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export function getIdentityTokenEndpointSuffix(tenantId) {
    if (tenantId === "adfs") {
        return "oauth2/token";
    }
    else {
        return "oauth2/v2.0/token";
    }
}//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/3fe68d450d4918f375c155b26a3a8e08f25b4e92/node_modules/@azure/identity/dist/esm/util/identityTokenEndpoint.js.map