// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { createClientLogger } from "@azure/logger";
export const logger = createClientLogger("core-rest-pipeline");//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/3fe68d450d4918f375c155b26a3a8e08f25b4e92/node_modules/@azure/core-rest-pipeline/dist/browser/log.js.map