// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export const SDK_VERSION = "0.3.5";
export const DEFAULT_RETRY_POLICY_COUNT = 3;//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/3fe68d450d4918f375c155b26a3a8e08f25b4e92/node_modules/@typespec/ts-http-runtime/dist/browser/constants.js.map