// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export { useInstrumenter } from "./instrumenter.js";
export { createTracingClient } from "./tracingClient.js";//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/3fe68d450d4918f375c155b26a3a8e08f25b4e92/node_modules/@azure/core-tracing/dist/esm/index.js.map