// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export { randomUUID } from "./uuidUtils.common.js";//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/3fe68d450d4918f375c155b26a3a8e08f25b4e92/node_modules/@typespec/ts-http-runtime/dist/react-native/util/uuidUtils.js.map